Basic Augmented Reality Demo.
===============================

.. image:: https://github.com/UCL/scikit-surgerybard/raw/master/project-icon.png
   :height: 128px
   :width: 128px
   :target: https://github.com/UCL/scikit-surgerybard
   :alt: Logo

.. image:: https://travis-ci.com/UCL/scikit-surgerybard.svg?branch=master
   :target: https://travis-ci.com/github/UCL/scikit-surgerybard
   :alt: Travis CI test status

.. image:: https://coveralls.io/repos/github/UCL/scikit-surgerybard/badge.svg?branch=master&service=github
    :target: https://coveralls.io/github/UCL/scikit-surgerybard?branch=master
    :alt: Test coverage

.. image:: https://readthedocs.org/projects/scikit-surgerybard/badge/?version=latest
    :target: http://scikit-surgerybard.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status



Author: Stephen Thompson

Basic Augmented Reality Demo. is part of the `SciKit-Surgery`_ software project, developed at the `Wellcome EPSRC Centre for Interventional and Surgical Sciences`_, part of `University College London (UCL)`_.

Basic Augmented Reality Demo. Python 3.6.

Basic Augmented Reality Demo. is intended to guide the user through using the SNAPPY Python template to create a well written and reusable algorithm library. It is intended to aid researchers in disseminating their work. 


Developing
----------

Contributing
^^^^^^^^^^^^

Please see the `contributing guidelines`_.


Useful links
^^^^^^^^^^^^

* `Source code repository`_
* `Documentation`_


Licensing and copyright
-----------------------

Copyright 2019 University College London.
Basic Augmented Reality Demo. is released under the BSD-3 license. Please see the `license file`_ for details.


Acknowledgements
----------------

Supported by `Wellcome`_ and `EPSRC`_.


.. _`Wellcome EPSRC Centre for Interventional and Surgical Sciences`: http://www.ucl.ac.uk/weiss
.. _`source code repository`: https://github.com/UCL/scikit-surgerybard
.. _`Documentation`: https://scikit-surgerybard.readthedocs.io
.. _`SciKit-Surgery`: https://github.com/UCL/scikit-surgery/wiki
.. _`University College London (UCL)`: http://www.ucl.ac.uk/
.. _`Wellcome`: https://wellcome.ac.uk/
.. _`EPSRC`: https://www.epsrc.ac.uk/
.. _`contributing guidelines`: https://github.com/UCL/scikit-surgerybard/blob/master/CONTRIBUTING.rst
.. _`license file`: https://github.com/UCL/scikit-surgerybard/blob/master/LICENSE

